cmd_/opt/anaconda1anaconda2anaconda3/i686-conda_cos6-linux-gnu/sysroot/usr/include/mtd/.install := perl /home/rdonnelly/mc/conda-bld/compilers_linux-32_1534858262098/work/.build/src/linux-2.6.32.71/scripts/headers_install.pl /home/rdonnelly/mc/conda-bld/compilers_linux-32_1534858262098/work/.build/src/linux-2.6.32.71/include/mtd /opt/anaconda1anaconda2anaconda3/i686-conda_cos6-linux-gnu/sysroot/usr/include/mtd x86 inftl-user.h mtd-abi.h mtd-user.h nftl-user.h ubi-user.h; perl /home/rdonnelly/mc/conda-bld/compilers_linux-32_1534858262098/work/.build/src/linux-2.6.32.71/scripts/headers_install.pl /home/rdonnelly/mc/conda-bld/compilers_linux-32_1534858262098/work/.build/i686-conda_cos6-linux-gnu/build/build-kernel-headers/include/mtd /opt/anaconda1anaconda2anaconda3/i686-conda_cos6-linux-gnu/sysroot/usr/include/mtd x86 ; touch /opt/anaconda1anaconda2anaconda3/i686-conda_cos6-linux-gnu/sysroot/usr/include/mtd/.install
